{% load cms_tags frontend %}
<{{ instance.tag_type }}{{ instance.get_attributes }}
id="{{ instance.uuid }}"
data-bs-children="{{ instance.collapse_siblings }}"
role="tablist"
>
{% with parent=instance %}
    {% for plugin in instance.child_plugin_instances %}
        {% with forloop as parentloop %}{% render_plugin plugin %}{% endwith %}
    {% endfor %}
{% endwith %}
</{{ instance.tag_type }}>
